### Name: Constants
### Title: Built-in Constants
### Aliases: LETTERS letters month.abb month.name pi
### Keywords: sysdata

### ** Examples

# John Machin (1705) computed 100 decimals of pi :
pi - 4*(4*atan(1/5) - atan(1/239))

## months in English
month.name
## months in your current locale
format(ISOdate(2000, 1:12, 1), "%B")
format(ISOdate(2000, 1:12, 1), "%b")



